# alfresco_api

AlfrescoAPI - the Ruby gem for the Alfresco Content Services REST API

**Core API**  Provides access to the core features of Alfresco Content Services.

This SDK is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.RubyClientCodegen

## Installation

  gem 'alfresco_api', '~> 1.0.0'

### Install from Git

  gem 'alfresco_api', :git => 'https://github.com/elissonmichael/alfresco_api_ruby.git'


## Getting Started

Please follow the [installation](#installation) procedure and then run the following code:
```ruby
# Load the gem
require 'alfresco_api'

# Setup authorization
AlfrescoAPI.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = AlfrescoAPI::ActivitiesApi.new

person_id = "person_id_example" # String | The identifier of a person.

opts = {
  skip_count: 0, # Integer | The number of entities that exist in the collection before those included in this list.  If not supplied then the default value is 0.
  max_items: 100, # Integer | The maximum number of items to return in the list.  If not supplied then the default value is 100.
  who: "who_example", # String | A filter to include the user's activities only `me`, other user's activities only `others`'
  site_id: "site_id_example", # String | Include only activity feed entries relating to this site.
  fields: ["fields_example"] # Array<String> | A list of field names.  You can use this parameter to restrict the fields returned within a response if, for example, you want to save on overall bandwidth.  The list applies to a returned individual entity or entries within a collection.  If the API method also supports the **include** parameter, then the fields specified in the **include** parameter are returned in addition to those specified in the **fields** parameter.
}

begin
  #List activities
  result = api_instance.list_activities_for_person(person_id, opts)
  p result
rescue AlfrescoAPI::ApiError => e
  puts "Exception when calling ActivitiesApi->list_activities_for_person: #{e}"
end

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost/alfresco/api/-default-/public/alfresco/versions/1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AlfrescoAPI::ActivitiesApi* | [**list_activities_for_person**](docs/ActivitiesApi.md#list_activities_for_person) | **GET** /people/{personId}/activities | List activities
*AlfrescoAPI::AuditApi* | [**delete_audit_entries_for_audit_app**](docs/AuditApi.md#delete_audit_entries_for_audit_app) | **DELETE** /audit-applications/{auditApplicationId}/audit-entries | Permanently delete audit entries for an audit application
*AlfrescoAPI::AuditApi* | [**delete_audit_entry**](docs/AuditApi.md#delete_audit_entry) | **DELETE** /audit-applications/{auditApplicationId}/audit-entries/{auditEntryId} | Permanently delete an audit entry
*AlfrescoAPI::AuditApi* | [**get_audit_app**](docs/AuditApi.md#get_audit_app) | **GET** /audit-applications/{auditApplicationId} | Get audit application info
*AlfrescoAPI::AuditApi* | [**get_audit_entry**](docs/AuditApi.md#get_audit_entry) | **GET** /audit-applications/{auditApplicationId}/audit-entries/{auditEntryId} | Get audit entry
*AlfrescoAPI::AuditApi* | [**list_audit_apps**](docs/AuditApi.md#list_audit_apps) | **GET** /audit-applications | List audit applications
*AlfrescoAPI::AuditApi* | [**list_audit_entries_for_audit_app**](docs/AuditApi.md#list_audit_entries_for_audit_app) | **GET** /audit-applications/{auditApplicationId}/audit-entries | List audit entries for an audit application
*AlfrescoAPI::AuditApi* | [**list_audit_entries_for_node**](docs/AuditApi.md#list_audit_entries_for_node) | **GET** /nodes/{nodeId}/audit-entries | List audit entries for a node
*AlfrescoAPI::AuditApi* | [**update_audit_app**](docs/AuditApi.md#update_audit_app) | **PUT** /audit-applications/{auditApplicationId} | Update audit application info
*AlfrescoAPI::CommentsApi* | [**create_comment**](docs/CommentsApi.md#create_comment) | **POST** /nodes/{nodeId}/comments | Create a comment
*AlfrescoAPI::CommentsApi* | [**delete_comment**](docs/CommentsApi.md#delete_comment) | **DELETE** /nodes/{nodeId}/comments/{commentId} | Delete a comment
*AlfrescoAPI::CommentsApi* | [**list_comments**](docs/CommentsApi.md#list_comments) | **GET** /nodes/{nodeId}/comments | List comments
*AlfrescoAPI::CommentsApi* | [**update_comment**](docs/CommentsApi.md#update_comment) | **PUT** /nodes/{nodeId}/comments/{commentId} | Update a comment
*AlfrescoAPI::DownloadsApi* | [**cancel_download**](docs/DownloadsApi.md#cancel_download) | **DELETE** /downloads/{downloadId} | Cancel a download
*AlfrescoAPI::DownloadsApi* | [**create_download**](docs/DownloadsApi.md#create_download) | **POST** /downloads | Create a new download
*AlfrescoAPI::DownloadsApi* | [**get_download**](docs/DownloadsApi.md#get_download) | **GET** /downloads/{downloadId} | Get a download
*AlfrescoAPI::FavoritesApi* | [**create_favorite**](docs/FavoritesApi.md#create_favorite) | **POST** /people/{personId}/favorites | Create a favorite
*AlfrescoAPI::FavoritesApi* | [**create_site_favorite**](docs/FavoritesApi.md#create_site_favorite) | **POST** /people/{personId}/favorite-sites | Create a site favorite
*AlfrescoAPI::FavoritesApi* | [**delete_favorite**](docs/FavoritesApi.md#delete_favorite) | **DELETE** /people/{personId}/favorites/{favoriteId} | Delete a favorite
*AlfrescoAPI::FavoritesApi* | [**delete_site_favorite**](docs/FavoritesApi.md#delete_site_favorite) | **DELETE** /people/{personId}/favorite-sites/{siteId} | Delete a site favorite
*AlfrescoAPI::FavoritesApi* | [**get_favorite**](docs/FavoritesApi.md#get_favorite) | **GET** /people/{personId}/favorites/{favoriteId} | Get a favorite
*AlfrescoAPI::FavoritesApi* | [**get_favorite_site**](docs/FavoritesApi.md#get_favorite_site) | **GET** /people/{personId}/favorite-sites/{siteId} | Get a favorite site
*AlfrescoAPI::FavoritesApi* | [**list_favorite_sites_for_person**](docs/FavoritesApi.md#list_favorite_sites_for_person) | **GET** /people/{personId}/favorite-sites | List favorite sites
*AlfrescoAPI::FavoritesApi* | [**list_favorites**](docs/FavoritesApi.md#list_favorites) | **GET** /people/{personId}/favorites | List favorites
*AlfrescoAPI::GroupsApi* | [**create_group**](docs/GroupsApi.md#create_group) | **POST** /groups | Create a group
*AlfrescoAPI::GroupsApi* | [**create_group_membership**](docs/GroupsApi.md#create_group_membership) | **POST** /groups/{groupId}/members | Create a group membership
*AlfrescoAPI::GroupsApi* | [**delete_group**](docs/GroupsApi.md#delete_group) | **DELETE** /groups/{groupId} | Delete a group
*AlfrescoAPI::GroupsApi* | [**delete_group_membership**](docs/GroupsApi.md#delete_group_membership) | **DELETE** /groups/{groupId}/members/{groupMemberId} | Delete a group membership
*AlfrescoAPI::GroupsApi* | [**get_group**](docs/GroupsApi.md#get_group) | **GET** /groups/{groupId} | Get group details
*AlfrescoAPI::GroupsApi* | [**list_group_memberships**](docs/GroupsApi.md#list_group_memberships) | **GET** /groups/{groupId}/members | List memberships of a group
*AlfrescoAPI::GroupsApi* | [**list_group_memberships_for_person**](docs/GroupsApi.md#list_group_memberships_for_person) | **GET** /people/{personId}/groups | List group memberships
*AlfrescoAPI::GroupsApi* | [**list_groups**](docs/GroupsApi.md#list_groups) | **GET** /groups | List groups
*AlfrescoAPI::GroupsApi* | [**update_group**](docs/GroupsApi.md#update_group) | **PUT** /groups/{groupId} | Update group details
*AlfrescoAPI::NetworksApi* | [**get_network**](docs/NetworksApi.md#get_network) | **GET** /networks/{networkId} | Get a network
*AlfrescoAPI::NetworksApi* | [**get_network_for_person**](docs/NetworksApi.md#get_network_for_person) | **GET** /people/{personId}/networks/{networkId} | Get network information
*AlfrescoAPI::NetworksApi* | [**list_networks_for_person**](docs/NetworksApi.md#list_networks_for_person) | **GET** /people/{personId}/networks | List network membership
*AlfrescoAPI::NodesApi* | [**copy_node**](docs/NodesApi.md#copy_node) | **POST** /nodes/{nodeId}/copy | Copy a node
*AlfrescoAPI::NodesApi* | [**create_assocation**](docs/NodesApi.md#create_assocation) | **POST** /nodes/{nodeId}/targets | Create node association
*AlfrescoAPI::NodesApi* | [**create_node**](docs/NodesApi.md#create_node) | **POST** /nodes/{nodeId}/children | Create a node
*AlfrescoAPI::NodesApi* | [**create_secondary_child_assocation**](docs/NodesApi.md#create_secondary_child_assocation) | **POST** /nodes/{nodeId}/secondary-children | Create secondary child
*AlfrescoAPI::NodesApi* | [**delete_assocation**](docs/NodesApi.md#delete_assocation) | **DELETE** /nodes/{nodeId}/targets/{targetId} | Delete node association(s)
*AlfrescoAPI::NodesApi* | [**delete_node**](docs/NodesApi.md#delete_node) | **DELETE** /nodes/{nodeId} | Delete a node
*AlfrescoAPI::NodesApi* | [**delete_secondary_child_assocation**](docs/NodesApi.md#delete_secondary_child_assocation) | **DELETE** /nodes/{nodeId}/secondary-children/{childId} | Delete secondary child or children
*AlfrescoAPI::NodesApi* | [**get_node**](docs/NodesApi.md#get_node) | **GET** /nodes/{nodeId} | Get a node
*AlfrescoAPI::NodesApi* | [**get_node_content**](docs/NodesApi.md#get_node_content) | **GET** /nodes/{nodeId}/content | Get node content
*AlfrescoAPI::NodesApi* | [**list_node_children**](docs/NodesApi.md#list_node_children) | **GET** /nodes/{nodeId}/children | List node children
*AlfrescoAPI::NodesApi* | [**list_parents**](docs/NodesApi.md#list_parents) | **GET** /nodes/{nodeId}/parents | List parents
*AlfrescoAPI::NodesApi* | [**list_secondary_children**](docs/NodesApi.md#list_secondary_children) | **GET** /nodes/{nodeId}/secondary-children | List secondary children
*AlfrescoAPI::NodesApi* | [**list_source_associations**](docs/NodesApi.md#list_source_associations) | **GET** /nodes/{nodeId}/sources | List source associations
*AlfrescoAPI::NodesApi* | [**list_target_associations**](docs/NodesApi.md#list_target_associations) | **GET** /nodes/{nodeId}/targets | List target associations
*AlfrescoAPI::NodesApi* | [**lock_node**](docs/NodesApi.md#lock_node) | **POST** /nodes/{nodeId}/lock | Lock a node
*AlfrescoAPI::NodesApi* | [**move_node**](docs/NodesApi.md#move_node) | **POST** /nodes/{nodeId}/move | Move a node
*AlfrescoAPI::NodesApi* | [**unlock_node**](docs/NodesApi.md#unlock_node) | **POST** /nodes/{nodeId}/unlock | Unlock a node
*AlfrescoAPI::NodesApi* | [**update_node**](docs/NodesApi.md#update_node) | **PUT** /nodes/{nodeId} | Update a node
*AlfrescoAPI::NodesApi* | [**update_node_content**](docs/NodesApi.md#update_node_content) | **PUT** /nodes/{nodeId}/content | Update node content
*AlfrescoAPI::PeopleApi* | [**create_person**](docs/PeopleApi.md#create_person) | **POST** /people | Create person
*AlfrescoAPI::PeopleApi* | [**delete_avatar_image**](docs/PeopleApi.md#delete_avatar_image) | **DELETE** /people/{personId}/avatar | Delete avatar image
*AlfrescoAPI::PeopleApi* | [**get_avatar_image**](docs/PeopleApi.md#get_avatar_image) | **GET** /people/{personId}/avatar | Get avatar image
*AlfrescoAPI::PeopleApi* | [**get_person**](docs/PeopleApi.md#get_person) | **GET** /people/{personId} | Get a person
*AlfrescoAPI::PeopleApi* | [**list_people**](docs/PeopleApi.md#list_people) | **GET** /people | List people
*AlfrescoAPI::PeopleApi* | [**request_password_reset**](docs/PeopleApi.md#request_password_reset) | **POST** /people/{personId}/request-password-reset | Request password reset
*AlfrescoAPI::PeopleApi* | [**reset_password**](docs/PeopleApi.md#reset_password) | **POST** /people/{personId}/reset-password | Reset password
*AlfrescoAPI::PeopleApi* | [**update_avatar_image**](docs/PeopleApi.md#update_avatar_image) | **PUT** /people/{personId}/avatar | Update avatar image
*AlfrescoAPI::PeopleApi* | [**update_person**](docs/PeopleApi.md#update_person) | **PUT** /people/{personId} | Update person
*AlfrescoAPI::PreferencesApi* | [**get_preference**](docs/PreferencesApi.md#get_preference) | **GET** /people/{personId}/preferences/{preferenceName} | Get a preference
*AlfrescoAPI::PreferencesApi* | [**list_preferences**](docs/PreferencesApi.md#list_preferences) | **GET** /people/{personId}/preferences | List preferences
*AlfrescoAPI::QueriesApi* | [**find_nodes**](docs/QueriesApi.md#find_nodes) | **GET** /queries/nodes | Find nodes
*AlfrescoAPI::QueriesApi* | [**find_people**](docs/QueriesApi.md#find_people) | **GET** /queries/people | Find people
*AlfrescoAPI::QueriesApi* | [**find_sites**](docs/QueriesApi.md#find_sites) | **GET** /queries/sites | Find sites
*AlfrescoAPI::RatingsApi* | [**create_rating**](docs/RatingsApi.md#create_rating) | **POST** /nodes/{nodeId}/ratings | Create a rating
*AlfrescoAPI::RatingsApi* | [**delete_rating**](docs/RatingsApi.md#delete_rating) | **DELETE** /nodes/{nodeId}/ratings/{ratingId} | Delete a rating
*AlfrescoAPI::RatingsApi* | [**get_rating**](docs/RatingsApi.md#get_rating) | **GET** /nodes/{nodeId}/ratings/{ratingId} | Get a rating
*AlfrescoAPI::RatingsApi* | [**list_ratings**](docs/RatingsApi.md#list_ratings) | **GET** /nodes/{nodeId}/ratings | List ratings
*AlfrescoAPI::RenditionsApi* | [**create_rendition**](docs/RenditionsApi.md#create_rendition) | **POST** /nodes/{nodeId}/renditions | Create rendition
*AlfrescoAPI::RenditionsApi* | [**get_rendition**](docs/RenditionsApi.md#get_rendition) | **GET** /nodes/{nodeId}/renditions/{renditionId} | Get rendition information
*AlfrescoAPI::RenditionsApi* | [**get_rendition_content**](docs/RenditionsApi.md#get_rendition_content) | **GET** /nodes/{nodeId}/renditions/{renditionId}/content | Get rendition content
*AlfrescoAPI::RenditionsApi* | [**list_renditions**](docs/RenditionsApi.md#list_renditions) | **GET** /nodes/{nodeId}/renditions | List renditions
*AlfrescoAPI::SharedlinksApi* | [**create_shared_link**](docs/SharedlinksApi.md#create_shared_link) | **POST** /shared-links | Create a shared link to a file
*AlfrescoAPI::SharedlinksApi* | [**delete_shared_link**](docs/SharedlinksApi.md#delete_shared_link) | **DELETE** /shared-links/{sharedId} | Deletes a shared link
*AlfrescoAPI::SharedlinksApi* | [**email_shared_link**](docs/SharedlinksApi.md#email_shared_link) | **POST** /shared-links/{sharedId}/email | Email shared link
*AlfrescoAPI::SharedlinksApi* | [**get_shared_link**](docs/SharedlinksApi.md#get_shared_link) | **GET** /shared-links/{sharedId} | Get a shared link
*AlfrescoAPI::SharedlinksApi* | [**get_shared_link_content**](docs/SharedlinksApi.md#get_shared_link_content) | **GET** /shared-links/{sharedId}/content | Get shared link content
*AlfrescoAPI::SharedlinksApi* | [**get_shared_link_rendition**](docs/SharedlinksApi.md#get_shared_link_rendition) | **GET** /shared-links/{sharedId}/renditions/{renditionId} | Get shared link rendition information
*AlfrescoAPI::SharedlinksApi* | [**get_shared_link_rendition_content**](docs/SharedlinksApi.md#get_shared_link_rendition_content) | **GET** /shared-links/{sharedId}/renditions/{renditionId}/content | Get shared link rendition content
*AlfrescoAPI::SharedlinksApi* | [**list_shared_link_renditions**](docs/SharedlinksApi.md#list_shared_link_renditions) | **GET** /shared-links/{sharedId}/renditions | List renditions for a shared link
*AlfrescoAPI::SharedlinksApi* | [**list_shared_links**](docs/SharedlinksApi.md#list_shared_links) | **GET** /shared-links | List shared links
*AlfrescoAPI::SitesApi* | [**create_site**](docs/SitesApi.md#create_site) | **POST** /sites | Create a site
*AlfrescoAPI::SitesApi* | [**create_site_membership**](docs/SitesApi.md#create_site_membership) | **POST** /sites/{siteId}/members | Create a site membership
*AlfrescoAPI::SitesApi* | [**create_site_membership_request_for_person**](docs/SitesApi.md#create_site_membership_request_for_person) | **POST** /people/{personId}/site-membership-requests | Create a site membership request
*AlfrescoAPI::SitesApi* | [**delete_site**](docs/SitesApi.md#delete_site) | **DELETE** /sites/{siteId} | Delete a site
*AlfrescoAPI::SitesApi* | [**delete_site_membership**](docs/SitesApi.md#delete_site_membership) | **DELETE** /sites/{siteId}/members/{personId} | Delete a site membership
*AlfrescoAPI::SitesApi* | [**delete_site_membership_for_person**](docs/SitesApi.md#delete_site_membership_for_person) | **DELETE** /people/{personId}/sites/{siteId} | Delete a site membership
*AlfrescoAPI::SitesApi* | [**delete_site_membership_request_for_person**](docs/SitesApi.md#delete_site_membership_request_for_person) | **DELETE** /people/{personId}/site-membership-requests/{siteId} | Delete a site membership request
*AlfrescoAPI::SitesApi* | [**get_site**](docs/SitesApi.md#get_site) | **GET** /sites/{siteId} | Get a site
*AlfrescoAPI::SitesApi* | [**get_site_container**](docs/SitesApi.md#get_site_container) | **GET** /sites/{siteId}/containers/{containerId} | Get a site container
*AlfrescoAPI::SitesApi* | [**get_site_membership**](docs/SitesApi.md#get_site_membership) | **GET** /sites/{siteId}/members/{personId} | Get a site membership
*AlfrescoAPI::SitesApi* | [**get_site_membership_for_person**](docs/SitesApi.md#get_site_membership_for_person) | **GET** /people/{personId}/sites/{siteId} | Get a site membership
*AlfrescoAPI::SitesApi* | [**get_site_membership_request_for_person**](docs/SitesApi.md#get_site_membership_request_for_person) | **GET** /people/{personId}/site-membership-requests/{siteId} | Get a site membership request
*AlfrescoAPI::SitesApi* | [**list_site_containers**](docs/SitesApi.md#list_site_containers) | **GET** /sites/{siteId}/containers | List site containers
*AlfrescoAPI::SitesApi* | [**list_site_membership_requests_for_person**](docs/SitesApi.md#list_site_membership_requests_for_person) | **GET** /people/{personId}/site-membership-requests | List site membership requests
*AlfrescoAPI::SitesApi* | [**list_site_memberships**](docs/SitesApi.md#list_site_memberships) | **GET** /sites/{siteId}/members | List site memberships
*AlfrescoAPI::SitesApi* | [**list_site_memberships_for_person**](docs/SitesApi.md#list_site_memberships_for_person) | **GET** /people/{personId}/sites | List site memberships
*AlfrescoAPI::SitesApi* | [**list_sites**](docs/SitesApi.md#list_sites) | **GET** /sites | List sites
*AlfrescoAPI::SitesApi* | [**update_site**](docs/SitesApi.md#update_site) | **PUT** /sites/{siteId} | Update a site
*AlfrescoAPI::SitesApi* | [**update_site_membership**](docs/SitesApi.md#update_site_membership) | **PUT** /sites/{siteId}/members/{personId} | Update a site membership
*AlfrescoAPI::SitesApi* | [**update_site_membership_request_for_person**](docs/SitesApi.md#update_site_membership_request_for_person) | **PUT** /people/{personId}/site-membership-requests/{siteId} | Update a site membership request
*AlfrescoAPI::TagsApi* | [**create_tag_for_node**](docs/TagsApi.md#create_tag_for_node) | **POST** /nodes/{nodeId}/tags | Create a tag for a node
*AlfrescoAPI::TagsApi* | [**delete_tag_from_node**](docs/TagsApi.md#delete_tag_from_node) | **DELETE** /nodes/{nodeId}/tags/{tagId} | Delete a tag from a node
*AlfrescoAPI::TagsApi* | [**get_tag**](docs/TagsApi.md#get_tag) | **GET** /tags/{tagId} | Get a tag
*AlfrescoAPI::TagsApi* | [**list_tags**](docs/TagsApi.md#list_tags) | **GET** /tags | List tags
*AlfrescoAPI::TagsApi* | [**list_tags_for_node**](docs/TagsApi.md#list_tags_for_node) | **GET** /nodes/{nodeId}/tags | List tags for a node
*AlfrescoAPI::TagsApi* | [**update_tag**](docs/TagsApi.md#update_tag) | **PUT** /tags/{tagId} | Update a tag
*AlfrescoAPI::TrashcanApi* | [**delete_deleted_node**](docs/TrashcanApi.md#delete_deleted_node) | **DELETE** /deleted-nodes/{nodeId} | Permanently delete a deleted node
*AlfrescoAPI::TrashcanApi* | [**get_archived_node_rendition**](docs/TrashcanApi.md#get_archived_node_rendition) | **GET** /deleted-nodes/{nodeId}/renditions/{renditionId} | Get rendition information for a deleted node
*AlfrescoAPI::TrashcanApi* | [**get_archived_node_rendition_content**](docs/TrashcanApi.md#get_archived_node_rendition_content) | **GET** /deleted-nodes/{nodeId}/renditions/{renditionId}/content | Get rendition content of a deleted node
*AlfrescoAPI::TrashcanApi* | [**get_deleted_node**](docs/TrashcanApi.md#get_deleted_node) | **GET** /deleted-nodes/{nodeId} | Get a deleted node
*AlfrescoAPI::TrashcanApi* | [**get_deleted_node_content**](docs/TrashcanApi.md#get_deleted_node_content) | **GET** /deleted-nodes/{nodeId}/content | Get deleted node content
*AlfrescoAPI::TrashcanApi* | [**list_deleted_node_renditions**](docs/TrashcanApi.md#list_deleted_node_renditions) | **GET** /deleted-nodes/{nodeId}/renditions | List renditions for a deleted node
*AlfrescoAPI::TrashcanApi* | [**list_deleted_nodes**](docs/TrashcanApi.md#list_deleted_nodes) | **GET** /deleted-nodes | List deleted nodes
*AlfrescoAPI::TrashcanApi* | [**restore_deleted_node**](docs/TrashcanApi.md#restore_deleted_node) | **POST** /deleted-nodes/{nodeId}/restore | Restore a deleted node
*AlfrescoAPI::VersionsApi* | [**delete_version**](docs/VersionsApi.md#delete_version) | **DELETE** /nodes/{nodeId}/versions/{versionId} | Delete a version
*AlfrescoAPI::VersionsApi* | [**get_version**](docs/VersionsApi.md#get_version) | **GET** /nodes/{nodeId}/versions/{versionId} | Get version information
*AlfrescoAPI::VersionsApi* | [**get_version_content**](docs/VersionsApi.md#get_version_content) | **GET** /nodes/{nodeId}/versions/{versionId}/content | Get version content
*AlfrescoAPI::VersionsApi* | [**list_version_history**](docs/VersionsApi.md#list_version_history) | **GET** /nodes/{nodeId}/versions | List version history
*AlfrescoAPI::VersionsApi* | [**revert_version**](docs/VersionsApi.md#revert_version) | **POST** /nodes/{nodeId}/versions/{versionId}/revert | Revert a version


## Documentation for Models

 - [AlfrescoAPI::Activity](docs/Activity.md)
 - [AlfrescoAPI::ActivityEntry](docs/ActivityEntry.md)
 - [AlfrescoAPI::ActivityPaging](docs/ActivityPaging.md)
 - [AlfrescoAPI::ActivityPagingList](docs/ActivityPagingList.md)
 - [AlfrescoAPI::Association](docs/Association.md)
 - [AlfrescoAPI::AssociationBody](docs/AssociationBody.md)
 - [AlfrescoAPI::AssociationEntry](docs/AssociationEntry.md)
 - [AlfrescoAPI::AssociationInfo](docs/AssociationInfo.md)
 - [AlfrescoAPI::AuditApp](docs/AuditApp.md)
 - [AlfrescoAPI::AuditAppEntry](docs/AuditAppEntry.md)
 - [AlfrescoAPI::AuditAppPaging](docs/AuditAppPaging.md)
 - [AlfrescoAPI::AuditAppPagingList](docs/AuditAppPagingList.md)
 - [AlfrescoAPI::AuditBodyUpdate](docs/AuditBodyUpdate.md)
 - [AlfrescoAPI::AuditEntry](docs/AuditEntry.md)
 - [AlfrescoAPI::AuditEntryEntry](docs/AuditEntryEntry.md)
 - [AlfrescoAPI::AuditEntryPaging](docs/AuditEntryPaging.md)
 - [AlfrescoAPI::AuditEntryPagingList](docs/AuditEntryPagingList.md)
 - [AlfrescoAPI::ChildAssociation](docs/ChildAssociation.md)
 - [AlfrescoAPI::ChildAssociationBody](docs/ChildAssociationBody.md)
 - [AlfrescoAPI::ChildAssociationEntry](docs/ChildAssociationEntry.md)
 - [AlfrescoAPI::ChildAssociationInfo](docs/ChildAssociationInfo.md)
 - [AlfrescoAPI::ClientBody](docs/ClientBody.md)
 - [AlfrescoAPI::Comment](docs/Comment.md)
 - [AlfrescoAPI::CommentBody](docs/CommentBody.md)
 - [AlfrescoAPI::CommentEntry](docs/CommentEntry.md)
 - [AlfrescoAPI::CommentPaging](docs/CommentPaging.md)
 - [AlfrescoAPI::CommentPagingList](docs/CommentPagingList.md)
 - [AlfrescoAPI::Company](docs/Company.md)
 - [AlfrescoAPI::ContentInfo](docs/ContentInfo.md)
 - [AlfrescoAPI::DeletedNode](docs/DeletedNode.md)
 - [AlfrescoAPI::DeletedNodeEntry](docs/DeletedNodeEntry.md)
 - [AlfrescoAPI::DeletedNodesPaging](docs/DeletedNodesPaging.md)
 - [AlfrescoAPI::DeletedNodesPagingList](docs/DeletedNodesPagingList.md)
 - [AlfrescoAPI::Download](docs/Download.md)
 - [AlfrescoAPI::DownloadBodyCreate](docs/DownloadBodyCreate.md)
 - [AlfrescoAPI::DownloadEntry](docs/DownloadEntry.md)
 - [AlfrescoAPI::Error](docs/Error.md)
 - [AlfrescoAPI::ErrorError](docs/ErrorError.md)
 - [AlfrescoAPI::Favorite](docs/Favorite.md)
 - [AlfrescoAPI::FavoriteBodyCreate](docs/FavoriteBodyCreate.md)
 - [AlfrescoAPI::FavoriteEntry](docs/FavoriteEntry.md)
 - [AlfrescoAPI::FavoritePaging](docs/FavoritePaging.md)
 - [AlfrescoAPI::FavoritePagingList](docs/FavoritePagingList.md)
 - [AlfrescoAPI::FavoriteSite](docs/FavoriteSite.md)
 - [AlfrescoAPI::FavoriteSiteBodyCreate](docs/FavoriteSiteBodyCreate.md)
 - [AlfrescoAPI::FavoriteSiteEntry](docs/FavoriteSiteEntry.md)
 - [AlfrescoAPI::Group](docs/Group.md)
 - [AlfrescoAPI::GroupBodyCreate](docs/GroupBodyCreate.md)
 - [AlfrescoAPI::GroupBodyUpdate](docs/GroupBodyUpdate.md)
 - [AlfrescoAPI::GroupEntry](docs/GroupEntry.md)
 - [AlfrescoAPI::GroupMember](docs/GroupMember.md)
 - [AlfrescoAPI::GroupMemberEntry](docs/GroupMemberEntry.md)
 - [AlfrescoAPI::GroupMemberPaging](docs/GroupMemberPaging.md)
 - [AlfrescoAPI::GroupMemberPagingList](docs/GroupMemberPagingList.md)
 - [AlfrescoAPI::GroupMembershipBodyCreate](docs/GroupMembershipBodyCreate.md)
 - [AlfrescoAPI::GroupPaging](docs/GroupPaging.md)
 - [AlfrescoAPI::GroupPagingList](docs/GroupPagingList.md)
 - [AlfrescoAPI::NetworkQuota](docs/NetworkQuota.md)
 - [AlfrescoAPI::Node](docs/Node.md)
 - [AlfrescoAPI::NodeAssociation](docs/NodeAssociation.md)
 - [AlfrescoAPI::NodeAssociationEntry](docs/NodeAssociationEntry.md)
 - [AlfrescoAPI::NodeAssociationPaging](docs/NodeAssociationPaging.md)
 - [AlfrescoAPI::NodeAssociationPagingList](docs/NodeAssociationPagingList.md)
 - [AlfrescoAPI::NodeBodyCopy](docs/NodeBodyCopy.md)
 - [AlfrescoAPI::NodeBodyCreate](docs/NodeBodyCreate.md)
 - [AlfrescoAPI::NodeBodyCreateAssociation](docs/NodeBodyCreateAssociation.md)
 - [AlfrescoAPI::NodeBodyLock](docs/NodeBodyLock.md)
 - [AlfrescoAPI::NodeBodyMove](docs/NodeBodyMove.md)
 - [AlfrescoAPI::NodeBodyUpdate](docs/NodeBodyUpdate.md)
 - [AlfrescoAPI::NodeChildAssociation](docs/NodeChildAssociation.md)
 - [AlfrescoAPI::NodeChildAssociationEntry](docs/NodeChildAssociationEntry.md)
 - [AlfrescoAPI::NodeChildAssociationPaging](docs/NodeChildAssociationPaging.md)
 - [AlfrescoAPI::NodeChildAssociationPagingList](docs/NodeChildAssociationPagingList.md)
 - [AlfrescoAPI::NodeEntry](docs/NodeEntry.md)
 - [AlfrescoAPI::NodePaging](docs/NodePaging.md)
 - [AlfrescoAPI::NodePagingList](docs/NodePagingList.md)
 - [AlfrescoAPI::Pagination](docs/Pagination.md)
 - [AlfrescoAPI::PasswordResetBody](docs/PasswordResetBody.md)
 - [AlfrescoAPI::PathElement](docs/PathElement.md)
 - [AlfrescoAPI::PathInfo](docs/PathInfo.md)
 - [AlfrescoAPI::PermissionElement](docs/PermissionElement.md)
 - [AlfrescoAPI::PermissionsBodyUpdate](docs/PermissionsBodyUpdate.md)
 - [AlfrescoAPI::PermissionsInfo](docs/PermissionsInfo.md)
 - [AlfrescoAPI::Person](docs/Person.md)
 - [AlfrescoAPI::PersonBodyCreate](docs/PersonBodyCreate.md)
 - [AlfrescoAPI::PersonBodyUpdate](docs/PersonBodyUpdate.md)
 - [AlfrescoAPI::PersonEntry](docs/PersonEntry.md)
 - [AlfrescoAPI::PersonNetwork](docs/PersonNetwork.md)
 - [AlfrescoAPI::PersonNetworkEntry](docs/PersonNetworkEntry.md)
 - [AlfrescoAPI::PersonNetworkPaging](docs/PersonNetworkPaging.md)
 - [AlfrescoAPI::PersonNetworkPagingList](docs/PersonNetworkPagingList.md)
 - [AlfrescoAPI::PersonPaging](docs/PersonPaging.md)
 - [AlfrescoAPI::PersonPagingList](docs/PersonPagingList.md)
 - [AlfrescoAPI::Preference](docs/Preference.md)
 - [AlfrescoAPI::PreferenceEntry](docs/PreferenceEntry.md)
 - [AlfrescoAPI::PreferencePaging](docs/PreferencePaging.md)
 - [AlfrescoAPI::PreferencePagingList](docs/PreferencePagingList.md)
 - [AlfrescoAPI::Rating](docs/Rating.md)
 - [AlfrescoAPI::RatingAggregate](docs/RatingAggregate.md)
 - [AlfrescoAPI::RatingBody](docs/RatingBody.md)
 - [AlfrescoAPI::RatingEntry](docs/RatingEntry.md)
 - [AlfrescoAPI::RatingPaging](docs/RatingPaging.md)
 - [AlfrescoAPI::RatingPagingList](docs/RatingPagingList.md)
 - [AlfrescoAPI::Rendition](docs/Rendition.md)
 - [AlfrescoAPI::RenditionBodyCreate](docs/RenditionBodyCreate.md)
 - [AlfrescoAPI::RenditionEntry](docs/RenditionEntry.md)
 - [AlfrescoAPI::RenditionPaging](docs/RenditionPaging.md)
 - [AlfrescoAPI::RenditionPagingList](docs/RenditionPagingList.md)
 - [AlfrescoAPI::RevertBody](docs/RevertBody.md)
 - [AlfrescoAPI::SharedLink](docs/SharedLink.md)
 - [AlfrescoAPI::SharedLinkBodyCreate](docs/SharedLinkBodyCreate.md)
 - [AlfrescoAPI::SharedLinkBodyEmail](docs/SharedLinkBodyEmail.md)
 - [AlfrescoAPI::SharedLinkEntry](docs/SharedLinkEntry.md)
 - [AlfrescoAPI::SharedLinkPaging](docs/SharedLinkPaging.md)
 - [AlfrescoAPI::SharedLinkPagingList](docs/SharedLinkPagingList.md)
 - [AlfrescoAPI::Site](docs/Site.md)
 - [AlfrescoAPI::SiteBodyCreate](docs/SiteBodyCreate.md)
 - [AlfrescoAPI::SiteBodyUpdate](docs/SiteBodyUpdate.md)
 - [AlfrescoAPI::SiteContainer](docs/SiteContainer.md)
 - [AlfrescoAPI::SiteContainerEntry](docs/SiteContainerEntry.md)
 - [AlfrescoAPI::SiteContainerPaging](docs/SiteContainerPaging.md)
 - [AlfrescoAPI::SiteContainerPagingList](docs/SiteContainerPagingList.md)
 - [AlfrescoAPI::SiteEntry](docs/SiteEntry.md)
 - [AlfrescoAPI::SiteMember](docs/SiteMember.md)
 - [AlfrescoAPI::SiteMemberEntry](docs/SiteMemberEntry.md)
 - [AlfrescoAPI::SiteMemberPaging](docs/SiteMemberPaging.md)
 - [AlfrescoAPI::SiteMemberPagingList](docs/SiteMemberPagingList.md)
 - [AlfrescoAPI::SiteMembershipBodyCreate](docs/SiteMembershipBodyCreate.md)
 - [AlfrescoAPI::SiteMembershipBodyUpdate](docs/SiteMembershipBodyUpdate.md)
 - [AlfrescoAPI::SiteMembershipRequest](docs/SiteMembershipRequest.md)
 - [AlfrescoAPI::SiteMembershipRequestBodyCreate](docs/SiteMembershipRequestBodyCreate.md)
 - [AlfrescoAPI::SiteMembershipRequestBodyUpdate](docs/SiteMembershipRequestBodyUpdate.md)
 - [AlfrescoAPI::SiteMembershipRequestEntry](docs/SiteMembershipRequestEntry.md)
 - [AlfrescoAPI::SiteMembershipRequestPaging](docs/SiteMembershipRequestPaging.md)
 - [AlfrescoAPI::SiteMembershipRequestPagingList](docs/SiteMembershipRequestPagingList.md)
 - [AlfrescoAPI::SitePaging](docs/SitePaging.md)
 - [AlfrescoAPI::SitePagingList](docs/SitePagingList.md)
 - [AlfrescoAPI::SiteRole](docs/SiteRole.md)
 - [AlfrescoAPI::SiteRoleEntry](docs/SiteRoleEntry.md)
 - [AlfrescoAPI::SiteRolePaging](docs/SiteRolePaging.md)
 - [AlfrescoAPI::SiteRolePagingList](docs/SiteRolePagingList.md)
 - [AlfrescoAPI::Tag](docs/Tag.md)
 - [AlfrescoAPI::TagBody](docs/TagBody.md)
 - [AlfrescoAPI::TagEntry](docs/TagEntry.md)
 - [AlfrescoAPI::TagPaging](docs/TagPaging.md)
 - [AlfrescoAPI::TagPagingList](docs/TagPagingList.md)
 - [AlfrescoAPI::UserInfo](docs/UserInfo.md)
 - [AlfrescoAPI::Version](docs/Version.md)
 - [AlfrescoAPI::VersionEntry](docs/VersionEntry.md)
 - [AlfrescoAPI::VersionPaging](docs/VersionPaging.md)
 - [AlfrescoAPI::VersionPagingList](docs/VersionPagingList.md)


## Documentation for Authorization


### basicAuth

- **Type**: HTTP basic authentication
